==> open-xchange-core_7.8.4.orig.tar.bz2: open-xchange-core-7.8.4/com.openexchange.pluginsloaded.mbean/src/com/openexchange/pluginsloaded/mbean/osgi/PluginsLoadedActivator.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.pluginsloaded.mbean.osgi;

import javax.management.ObjectName;
import org.slf4j.Logger;
import com.openexchange.management.ManagementService;
import com.openexchange.management.Managements;
import com.openexchange.osgi.HousekeepingActivator;
import com.openexchange.pluginsloaded.PluginsLoadedService;
import com.openexchange.pluginsloaded.mbean.PluginsLoadedMBean;
import com.openexchange.pluginsloaded.mbean.impl.PluginsLoadedMBeanImpl;


/**
 * {@link PluginsLoadedActivator}
 *
 * @author <a href="mailto:Jan-Oliver.Huhn@open-xchange.com">Jan-Oliver Huhn</a>
 * @since v7.8.4
 */
public class PluginsLoadedActivator extends HousekeepingActivator {
    
    static final Logger LOGGER = org.slf4j.LoggerFactory.getLogger(PluginsLoadedActivator.class);
    
    public PluginsLoadedActivator(){
        super();
    }
    
    @Override
    protected boolean stopOnServiceUnavailability() {
        return true;
    }
    
    @Override
    protected Class<?>[] getNeededServices() {
        return new Class<?>[] { ManagementService.class, PluginsLoadedService.class };
    }

    @Override
    protected void startBundle() throws Exception {
        ManagementService managementService = getService(ManagementService.class);
        PluginsLoadedService pluginsLoadedService = getService(PluginsLoadedService.class);
        
        try {
            final ObjectName objectName = Managements.getObjectName(PluginsLoadedMBean.class.getName(), PluginsLoadedMBean.DOMAIN);
            managementService.registerMBean(objectName, new PluginsLoadedMBeanImpl(pluginsLoadedService));
            LOGGER.info("Registered MBean {}", PluginsLoadedMBean.class.getName());
        } catch (Exception e) {
            LOGGER.warn("Could not register MBean {}", PluginsLoadedMBean.class.getName(), e);
        }
    }

}

==> open-xchange-core_7.10.4.orig.tar.bz2: open-xchange-core-7.10.4/com.openexchange.pluginsloaded.mbean/src/com/openexchange/pluginsloaded/mbean/osgi/PluginsLoadedActivator.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.pluginsloaded.mbean.osgi;

import org.slf4j.Logger;
import com.openexchange.management.ManagementService;
import com.openexchange.management.osgi.HousekeepingManagementTracker;
import com.openexchange.osgi.HousekeepingActivator;
import com.openexchange.pluginsloaded.PluginsLoadedService;
import com.openexchange.pluginsloaded.mbean.PluginsLoadedMBean;
import com.openexchange.pluginsloaded.mbean.impl.PluginsLoadedMBeanImpl;


/**
 * {@link PluginsLoadedActivator}
 *
 * @author <a href="mailto:Jan-Oliver.Huhn@open-xchange.com">Jan-Oliver Huhn</a>
 * @since v7.8.4
 */
public class PluginsLoadedActivator extends HousekeepingActivator {

    static final Logger LOGGER = org.slf4j.LoggerFactory.getLogger(PluginsLoadedActivator.class);

    public PluginsLoadedActivator(){
        super();
    }

    @Override
    protected boolean stopOnServiceUnavailability() {
        return true;
    }

    @Override
    protected Class<?>[] getNeededServices() {
        return new Class<?>[] { PluginsLoadedService.class };
    }

    @Override
    protected void startBundle() throws Exception {
        PluginsLoadedService pluginsLoadedService = getService(PluginsLoadedService.class);
        track(ManagementService.class, new HousekeepingManagementTracker(   context, 
                                                                            PluginsLoadedMBean.class.getName(), 
                                                                            PluginsLoadedMBean.DOMAIN, 
                                                                            new PluginsLoadedMBeanImpl(pluginsLoadedService)));
        openTrackers();
    }

}
